/*
 * Copyright 2022 University of Liège
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

// SWIG input file of the 'flow' module

%feature("autodoc","1");

%module(docstring=
"'floww' module: full potential solver 2018-2021
(c) ULg - A&M",
directors="0",
threads="1"
) floww
%{

#include "flow.h"

#include "fwkw.h"
#include "tboxw.h"
#include "floww.h"

%}


%include "fwkw.swg"

// ----------- MODULES UTILISES ------------
%import "tboxw.i"

// ----------- FLOW CLASSES ----------------
%include "flow.h"

%shared_ptr(flow::Medium);
%shared_ptr(flow::Assign);
%shared_ptr(flow::Initial);
%shared_ptr(flow::Dirichlet);
%shared_ptr(flow::Freestream);
%shared_ptr(flow::Wake);
%shared_ptr(flow::Kutta);
%shared_ptr(flow::Blowing);
%shared_ptr(flow::Boundary);
%shared_ptr(flow::Problem);
%shared_ptr(flow::Solver);
%shared_ptr(flow::Picard);
%shared_ptr(flow::Newton);
%shared_ptr(flow::Adjoint);

%include "wMedium.h"
%include "wAssign.h"
%include "wFreestream.h"
%warnfilter(509); // Shadowed constructor. Code compiling and running.
%include "wWake.h"
%include "wKutta.h"
%include "wBoundary.h"
%include "wBlowing.h"
%warnfilter(+509);
%include "wWakeElement.h"
%include "wKuttaElement.h"

%immutable flow::Problem::msh; // read-only variable (no setter)
%include "wProblem.h"

%immutable flow::Solver::pbl;
%immutable flow::Solver::linsol; // read-only variable (no setter)
%include "wSolver.h"
%include "wPicard.h"
%include "wNewton.h"

%immutable flow::Adjoint::sol;
%immutable flow::Adjoint::def;
%immutable flow::Adjoint::linsol; // read-only variable (no setter)
%include "wAdjoint.h"
