/*
 * Copyright 2022 University of Liège
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#include "wF0Ps.h"
using namespace tbox;
using namespace flow;

F0PsPhiInf::F0PsPhiInf(int _nDim, double _alpha, double _beta) : F0Ps(),
                                                                 nDim(_nDim),
                                                                 alpha(_alpha),
                                                                 beta(_beta)
{
    // Sanity check
    if (nDim != 2 && nDim != 3)
    {
        std::stringstream err;
        err << "F0PsPhiInf::nDim should be equal to 2 or 3 but " << nDim << " was given!\n";
        throw std::runtime_error(err.str());
    }
    if (nDim != 3 && beta != 0)
        throw std::runtime_error("F0PsPhiInf::beta can be nonzero only for 3D cases!\n");
}
/**
 * @brief Update the angle of attack
 */
void F0PsPhiInf::update(double _alpha)
{
    alpha = _alpha;
}
/**
 * @brief Evaluate the freestream potential
 */
double F0PsPhiInf::eval(Eigen::Vector3d const &pos) const
{
    if (nDim == 2)
        return cos(alpha) * pos(0) + sin(alpha) * pos(1);
    else
        return cos(alpha) * cos(beta) * pos(0) + sin(beta) * pos(1) + sin(alpha) * cos(beta) * pos(2);
}
