#!/usr/bin/env python3
# -*- coding: utf-8 -*-

# Copyright 2022 University of Liège
# 
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
# 
#     http://www.apache.org/licenses/LICENSE-2.0
# 
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.


# simple test on a square using 'heat'

import heat as h
import heat.utils
import tbox
import tbox.gmsh as gmsh

def main(**d):
    
    # default params
    p={}
    p['Lx'] = 10.
    p['Ly'] = 10.
    p['Nx'] = 10    # structured mesh params
    p['Ny'] = 10
    p['lc'] = 0.5   # unstructured mesh params
    p['stru'] = False 
    p['src'] = False 
    p['bc'] = 'dirichletx'
    p.update(d)    

    # configure/build mesh
    if p['stru']:
        pars={ 'Lx' : p['Lx'] , 'Ly' : p['Ly'], 'Nx' : p['Nx'], 'Ny' : p['Ny']}
        msh = gmsh.MeshLoader("rect_stru.geo",__file__).execute(**pars)    
    else:
        pars={ 'Lx' : p['Lx'] , 'Ly' : p['Ly'], 'lc' : p['lc']}
        msh = gmsh.MeshLoader("rect.geo",__file__).execute(**pars)
    # define mesh writer
    gmshWriter = tbox.GmshExport(msh)

    pbl = h.Problem(msh)

    # medium/boundary conditions
    pbl.add(h.Medium(msh, "S1", tbox.Fct2C(1e-5,1e-5, 0)))
    
    if p['bc']=='dirichletx':
        pbl.add(h.Dirichlet(msh,"Left",  3.))
        pbl.add(h.Dirichlet(msh,"Right", 5.))
    elif p['bc']=='dirichlety':
        pbl.add(h.Dirichlet(msh,"Bottom", 3.))
        pbl.add(h.Dirichlet(msh,"Top",    5.))

    if p['src']:    
        pbl.add(h.Source(msh, "S1", tbox.Fct0C(1e-6)))

    # solve problem
    solver = heat.utils.solve(pbl, gmshWriter)  
    return solver


if __name__ == "__main__":
    main()
