#!/usr/bin/env python3
# -*- coding: utf-8 -*-

# Copyright 2022 University of Liège
# 
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
# 
#     http://www.apache.org/licenses/LICENSE-2.0
# 
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

import tbox
import heat as h

def solve(pbl, writer):

    from fwk.wutils import parseargs
    args = parseargs()
    
    from tbox.solvers import LinearSolver
    solver = h.Solver(pbl, LinearSolver().pardiso())
    solver.nthreads = args.k
    solver.restol = 1e-6
    solver.start(writer)

    if not args.nogui:
        from heat.viewer import GUI
        GUI().open( pbl.msh.name ) 
           
    return solver

def getTemp(solver, linelabel="Bottom", sort='x'):
    """
    extract x,y,T on a line & return 3 numpy arrays
    """     
    nodes_bot = tbox.Group(solver.pbl.msh, linelabel)
    extr = h.Extractor(solver, nodes_bot)

    import numpy as np
    v = np.array(extr.execute())
    
    nos = np.zeros_like(v, dtype=np.int)
    nxs = np.zeros_like(v)
    nys = np.zeros_like(v)
    for i in range(len(v)):
        n = extr.nodes[i]
        nos[i] = n.no
        nxs[i] = n.pos[0]
        nys[i] = n.pos[1]
    if sort=='x':  
        iis = np.argsort(nxs)
    else:
        iis = np.argsort(nys)
    return (nxs[iis], nys[iis], v[iis])


def simpleplot(x, y, xlabel='x',title=''):

    # plot results using matplotlib
    from fwk.wutils import parseargs
    args = parseargs()
    if not args.nogui:
        import matplotlib.pyplot as plt
        plt.plot(x, y, 'bo-',lw=2)   
        plt.xlabel(xlabel)
        #plt.ylim(0,150)
        plt.title(title)
        plt.grid(True)
        plt.show()

    
