#!/usr/bin/env python3
# -*- coding: utf-8; -*-

import katoptron.CMAME.model as model

import katoptron as m
import tbox
import tbox.gmsh as gmsh
import shlex
import subprocess
import os
import numpy as np

from fwk.wutils import parseargs

from PyTrilinos import Teuchos

import katoptron.utilities as u


def evaluate_one_ensemble(ensemble_size, index, msh, comm, file_dir):

    work_dir = os.getcwd()
    args = parseargs()

    nuw = 128

    p = model.defaut_params
    p["Correlation length"] = 5.
    p["Wavenumber cutoff"] = 8.
    p["Wavenumber discretization points"] = nuw

    p["Number Z of previously drawn samples"] = index*nuw**2
    p["Number Phi of previously drawn samples"] = index*nuw**2

    p["Is exp"] = False

    pm = model.plate_model(
        ensemble_size, [0.], msh, comm, file_dir, work_dir, p)
    pm.run(args.k)


def evaluate_all_ensembles(ensemble_size, N, msh, comm, file_dir):

    directory = str(ensemble_size)
    if not os.path.exists(directory):
        os.makedirs(directory)
    os.chdir(directory)

    N_ensemble = (N // ensemble_size)
    for ensemble_index in range(0, N_ensemble):
        directory = str(ensemble_index)
        if not os.path.exists(directory):
            os.makedirs(directory)
        os.chdir(directory)

        evaluate_one_ensemble(
            ensemble_size, ensemble_index, msh, comm, file_dir)

        os.chdir('..')

    os.chdir('..')


def main():
    try:
        import mpi4py.MPI as mpi
        comm = mpi.COMM_WORLD
        rank = comm.rank
        siz = comm.size
        name = mpi.Get_processor_name()
        status = mpi.Status()
        print("info: MPI found")
    except:
        comm = None
        rank = 0
        siz = 1
        name = "noname"
        print("info: MPI not found => MPI disabled")
    args = parseargs()

    file_dir = os.path.dirname(__file__)
    work_dir = os.getcwd()

    # Units in the meshes are in mm
    msh = u.fuse_meshes('plate_1.msh', 'plate_1_tmp', 'plate_2.msh',
                        'plate_2_tmp', 'plate_fused', file_dir, work_dir)

    N = 2

    evaluate_all_ensembles(1, N, msh, comm, file_dir)


if __name__ == "__main__":
    main()
