#!/usr/bin/env python3
# -*- coding: utf-8; -*-

from katoptron.readers import *


def read_iter_all_ensemble_sizes(n_samples, ensemble_sizes, file_MC_base_dir, reduction=False):
    iter = np.zeros((len(ensemble_sizes), n_samples))
    for i in range(0, len(ensemble_sizes)):
        file_MC_base_dir_2 = file_MC_base_dir + \
            '/' + str(ensemble_sizes[i])+'/'
        for j in range(0, int((n_samples // ensemble_sizes[i]))):
            input_MC_file_dir = file_MC_base_dir_2 + str(j)+'/'
            es = ensemble_sizes[i]
            if reduction:
                es = 1
            iter_indices, residuals = read_Belos(
                input_MC_file_dir + 'belos_out.txt', es)
            for k in range(0, ensemble_sizes[i]):
                iter[i][j*ensemble_sizes[i]+k] = iter_indices[-1]
    return iter


def plot_iter_all_ensemble_sizes(n_samples, iter, print_all=False):
    import matplotlib.pyplot as plt
    plt.figure()
    plt.plot(list(range(0, n_samples)),
             iter[0][:], 'bo', markersize=8, zorder=1)
    ensemble_size = 8
    for i in range(0, int(np.ceil(n_samples*1./ensemble_size))):
        plt.plot(list(range(ensemble_size*i, ensemble_size*(i+1))),
                 iter[1][ensemble_size*i:ensemble_size*(i+1)], '-ro', linewidth=3, markersize=6, zorder=2)
    if print_all:
        ensemble_size = 16
        for i in range(0, int(np.ceil(n_samples*1./ensemble_size))):
            plt.plot(list(range(ensemble_size*i, ensemble_size*(i+1))),
                     iter[2][ensemble_size*i:ensemble_size*(i+1)], '-go', linewidth=2, markersize=4, zorder=2)
        ensemble_size = 32
        for i in range(0, int(np.ceil(n_samples*1./ensemble_size))):
            plt.plot(list(range(ensemble_size*i, ensemble_size*(i+1))),
                     iter[3][ensemble_size*i:ensemble_size*(i+1)], '-ko', linewidth=1, markersize=2, zorder=3)
    plt.xlabel('sample')
    plt.ylabel('Number of iterations to converge')


def main():
    import matplotlib.pyplot as plt

    n_samples = 8
    ensemble_sizes = [1, 8]
    for case_id in range(1, 2):
        file_MC_base_dir = '/Users/kimliegeois/Desktop/tests_plate_vd/katoptron_CMAME_tests_plate_vd_Direct_3'
        iter = read_iter_all_ensemble_sizes(
            n_samples, ensemble_sizes, file_MC_base_dir, True)
        plot_iter_all_ensemble_sizes(n_samples, iter)
        plt.savefig('Direct_3.png', dpi=400)
        np.savetxt('Direct_3.txt', iter, delimiter=' ')
        file_MC_base_dir = '/Users/kimliegeois/Desktop/tests_plate_vd/katoptron_CMAME_tests_plate_vd_Direct_200'
        try:
            iter = read_iter_all_ensemble_sizes(
                n_samples, ensemble_sizes, file_MC_base_dir, True)
            plot_iter_all_ensemble_sizes(n_samples, iter)
            plt.savefig('Direct_200.png', dpi=400)
            np.savetxt('Direct_200.txt', iter, delimiter=' ')
        except:
            print(file_MC_base_dir + ' has not all the files')
        file_MC_base_dir = '/Users/kimliegeois/Desktop/tests_plate_vd/katoptron_CMAME_tests_plate_vd_GS_3'
        try:
            iter = read_iter_all_ensemble_sizes(
                n_samples, ensemble_sizes, file_MC_base_dir, True)
            plot_iter_all_ensemble_sizes(n_samples, iter)
            plt.grid()
            plt.ylim([0, 850])
            plt.savefig('GS_3.png', dpi=400)
            np.savetxt('GS_3.txt', iter, delimiter=' ')
        except:
            print(file_MC_base_dir + ' has not all the files')
        file_MC_base_dir = '/Users/kimliegeois/Desktop/tests_plate_vd/katoptron_CMAME_tests_plate_vd_GS_200'
        try:
            iter = read_iter_all_ensemble_sizes(
                n_samples, ensemble_sizes, file_MC_base_dir, True)
            plot_iter_all_ensemble_sizes(n_samples, iter)
            plt.grid()
            plt.ylim([0, 850])
            plt.savefig('GS_200.png', dpi=400)
            np.savetxt('GS_200.txt', iter, delimiter=' ')
        except:
            print(file_MC_base_dir + ' has not all the files')
        file_MC_base_dir = '/Users/kimliegeois/Desktop/katoptron_CMAME_tests_plate_vd_GS/katoptron_CMAME_tests_plate_vd_GS_3'
        try:
            iter = read_iter_all_ensemble_sizes(
                n_samples, ensemble_sizes, file_MC_base_dir, True)
            plot_iter_all_ensemble_sizes(n_samples, iter)
            plt.grid()
            plt.ylim([0, 850])
            plt.savefig('GS_3_005.png', dpi=400)
            np.savetxt('GS_3_005.txt', iter, delimiter=' ')
        except:
            print(file_MC_base_dir + ' has not all the files')
        file_MC_base_dir = '/Users/kimliegeois/Desktop/katoptron_CMAME_tests_plate_vd_GS/katoptron_CMAME_tests_plate_vd_GS_200'
        try:
            iter = read_iter_all_ensemble_sizes(
                n_samples, ensemble_sizes, file_MC_base_dir, True)
            plot_iter_all_ensemble_sizes(n_samples, iter)
            plt.grid()
            plt.ylim([0, 850])
            plt.savefig('GS_200_005.png', dpi=400)
            np.savetxt('GS_200_005.txt', iter, delimiter=' ')
        except:
            print(file_MC_base_dir + ' has not all the files')
        file_MC_base_dir = '/Users/kimliegeois/Desktop/katoptron_CMAME_tests_plate_vd_GS_2/katoptron_CMAME_tests_plate_vd_GS_3'
        try:
            iter = read_iter_all_ensemble_sizes(
                n_samples, ensemble_sizes, file_MC_base_dir, True)
            plot_iter_all_ensemble_sizes(n_samples, iter)
            plt.grid()
            plt.ylim([0, 850])
            plt.savefig('GS_3_0005.png', dpi=400)
            np.savetxt('GS_3_0005.txt', iter, delimiter=' ')
        except:
            print(file_MC_base_dir + ' has not all the files')
        file_MC_base_dir = '/Users/kimliegeois/Desktop/katoptron_CMAME_tests_plate_vd_GS_2/katoptron_CMAME_tests_plate_vd_GS_200'
        try:
            iter = read_iter_all_ensemble_sizes(
                n_samples, ensemble_sizes, file_MC_base_dir, True)
            plot_iter_all_ensemble_sizes(n_samples, iter)
            plt.grid()
            plt.ylim([0, 850])
            plt.savefig('GS_200_0005.png', dpi=400)
            np.savetxt('GS_200_0005.txt', iter, delimiter=' ')
        except:
            print(file_MC_base_dir + ' has not all the files')
        file_MC_base_dir = '/Users/kimliegeois/Desktop/katoptron_CMAME_tests_plate_vd_GS_3/katoptron_CMAME_tests_plate_vd_GS_3'
        try:
            iter = read_iter_all_ensemble_sizes(
                n_samples, ensemble_sizes, file_MC_base_dir, True)
            plot_iter_all_ensemble_sizes(n_samples, iter)
            plt.grid()
            plt.ylim([0, 850])
            plt.savefig('GS_3_0005_group.png', dpi=400)
            np.savetxt('GS_3_0005_group.txt', iter, delimiter=' ')
        except:
            print(file_MC_base_dir + ' has not all the files')
        file_MC_base_dir = '/Users/kimliegeois/Desktop/katoptron_CMAME_tests_plate_vd_GS_3/katoptron_CMAME_tests_plate_vd_GS_200'
        try:
            iter = read_iter_all_ensemble_sizes(
                n_samples, ensemble_sizes, file_MC_base_dir, True)
            plot_iter_all_ensemble_sizes(n_samples, iter)
            plt.grid()
            plt.ylim([0, 850])
            plt.savefig('GS_200_0005_group.png', dpi=400)
            np.savetxt('GS_200_0005_group.txt', iter, delimiter=' ')
        except:
            print(file_MC_base_dir + ' has not all the files')
        file_MC_base_dir = '/Users/kimliegeois/Desktop/katoptron_CMAME_tests_plate_vd_GS_3_2'
        try:
            iter = read_iter_all_ensemble_sizes(
                n_samples, ensemble_sizes, file_MC_base_dir, True)
            plot_iter_all_ensemble_sizes(n_samples, iter)
            plt.grid()
            plt.ylim([0, 850])
            plt.savefig('GS_3_no_gamma.png', dpi=400)
            np.savetxt('GS_3_no_gamma.txt', iter, delimiter=' ')
        except:
            print(file_MC_base_dir + ' has not all the files')
        n_samples = 32
        ensemble_sizes = [1, 8, 16, 32]
        file_MC_base_dir = '/Volumes/HD_SONY/CMAME/Plate/fused/katoptron_CMAME_tests_fused_plate_MC_GS_all_cases/case_1'
        try:
            iter = read_iter_all_ensemble_sizes(
                n_samples, ensemble_sizes, file_MC_base_dir, True)
            plot_iter_all_ensemble_sizes(n_samples, iter, True)
            plt.grid()
            plt.ylim([40, 100])
            plt.savefig('SPD_case_1_MG.png', dpi=400)
            np.savetxt('SPD_case_1_MG.txt', iter, delimiter=' ')
        except:
            print(file_MC_base_dir + ' has not all the files')
        file_MC_base_dir = '/Volumes/HD_SONY/CMAME/Plate/fused/katoptron_CMAME_tests_fused_plate_MC_GS_all_cases/case_2'
        try:
            iter = read_iter_all_ensemble_sizes(
                n_samples, ensemble_sizes, file_MC_base_dir, True)
            plot_iter_all_ensemble_sizes(n_samples, iter, True)
            plt.grid()
            plt.ylim([40, 100])
            plt.savefig('SPD_case_2_MG.png', dpi=400)
            np.savetxt('SPD_case_2_MG.txt', iter, delimiter=' ')
        except:
            print(file_MC_base_dir + ' has not all the files')
        file_MC_base_dir = '/Volumes/HD_SONY/CMAME/Plate/fused/katoptron_CMAME_tests_fused_plate_MC_GS_all_cases/case_3'
        try:
            iter = read_iter_all_ensemble_sizes(
                n_samples, ensemble_sizes, file_MC_base_dir, True)
            plot_iter_all_ensemble_sizes(n_samples, iter, True)
            plt.grid()
            plt.ylim([0, 150])
            plt.savefig('SPD_case_3_MG.png', dpi=400)
            np.savetxt('SPD_case_3_MG.txt', iter, delimiter=' ')
        except:
            print(file_MC_base_dir + ' has not all the files')
        file_MC_base_dir = '/Volumes/HD_SONY/CMAME/Plate/fused/katoptron_CMAME_tests_fused_plate_MC_GS_all_cases/case_4'
        try:
            iter = read_iter_all_ensemble_sizes(
                n_samples, ensemble_sizes, file_MC_base_dir, True)
            plot_iter_all_ensemble_sizes(n_samples, iter, True)
            plt.grid()
            plt.ylim([0, 150])
            plt.savefig('SPD_case_4_MG.png', dpi=400)
            np.savetxt('SPD_case_4_MG.txt', iter, delimiter=' ')
        except:
            print(file_MC_base_dir + ' has not all the files')
        file_MC_base_dir = '/Volumes/HD_SONY/CMAME/Plate/fused/katoptron_CMAME_tests_fused_plate_MC_GS_all_cases/case_5'
        try:
            iter = read_iter_all_ensemble_sizes(
                n_samples, ensemble_sizes, file_MC_base_dir, True)
            plot_iter_all_ensemble_sizes(n_samples, iter, True)
            plt.grid()
            plt.ylim([0, 150])
            plt.savefig('SPD_case_5_MG.png', dpi=400)
            np.savetxt('SPD_case_5_MG.txt', iter, delimiter=' ')
        except:
            print(file_MC_base_dir + ' has not all the files')
        file_MC_base_dir = '/Volumes/HD_SONY/CMAME/Plate/fused/katoptron_CMAME_tests_fused_plate_MC_GS_all_cases/case_6'
        try:
            iter = read_iter_all_ensemble_sizes(
                n_samples, ensemble_sizes, file_MC_base_dir, True)
            plot_iter_all_ensemble_sizes(n_samples, iter, True)
            plt.grid()
            plt.ylim([0, 150])
            plt.savefig('SPD_case_6_MG.png', dpi=400)
            np.savetxt('SPD_case_6_MG.txt', iter, delimiter=' ')
        except:
            print(file_MC_base_dir + ' has not all the files')

        n_samples = 896
        file_MC_base_dir = '/Volumes/HD_SONY/CMAME/Plate/MG/all/katoptron_CMAME_tests_plate_MC_MG_all_cases/case_1'
        try:
            iter = read_iter_all_ensemble_sizes(
                n_samples, ensemble_sizes, file_MC_base_dir, False)
            plot_iter_all_ensemble_sizes(n_samples, iter, True)
            plt.grid()
            plt.ylim([75, 150])
            plt.savefig('MC_MG_case_1.png', dpi=400)
            np.savetxt('MC_MG_case_1.txt', np.transpose(iter), delimiter=' ')
        except:
            print(file_MC_base_dir + ' has not all the files')
        file_MC_base_dir = '/Volumes/HD_SONY/CMAME/Plate/MG/all/katoptron_CMAME_tests_plate_MC_MG_all_cases/case_2'
        try:
            iter = read_iter_all_ensemble_sizes(
                n_samples, ensemble_sizes, file_MC_base_dir, False)
            plot_iter_all_ensemble_sizes(n_samples, iter, True)
            plt.grid()
            plt.ylim([75, 150])
            plt.savefig('MC_MG_case_2.png', dpi=400)
            np.savetxt('MC_MG_case_2.txt', np.transpose(iter), delimiter=' ')
        except:
            print(file_MC_base_dir + ' has not all the files')
        file_MC_base_dir = '/Volumes/HD_SONY/CMAME/Plate/MG/all/katoptron_CMAME_tests_plate_MC_MG_all_cases/case_3'
        try:
            iter = read_iter_all_ensemble_sizes(
                n_samples, ensemble_sizes, file_MC_base_dir, False)
            plot_iter_all_ensemble_sizes(n_samples, iter, True)
            plt.grid()
            plt.ylim([75, 150])
            plt.savefig('MC_MG_case_3.png', dpi=400)
            np.savetxt('MC_MG_case_3.txt', np.transpose(iter), delimiter=' ')
        except:
            print(file_MC_base_dir + ' has not all the files')
        file_MC_base_dir = '/Volumes/HD_SONY/CMAME/Plate/MG/all/katoptron_CMAME_tests_plate_MC_MG_all_cases/case_4'
        try:
            iter = read_iter_all_ensemble_sizes(
                n_samples, ensemble_sizes, file_MC_base_dir, False)
            plot_iter_all_ensemble_sizes(n_samples, iter, True)
            plt.grid()
            plt.ylim([75, 150])
            plt.savefig('MC_MG_case_4.png', dpi=400)
            np.savetxt('MC_MG_case_4.txt', np.transpose(iter), delimiter=' ')
        except:
            print(file_MC_base_dir + ' has not all the files')
        file_MC_base_dir = '/Volumes/HD_SONY/CMAME/Plate/MG/all/katoptron_CMAME_tests_plate_MC_MG_all_cases/case_5'
        try:
            iter = read_iter_all_ensemble_sizes(
                n_samples, ensemble_sizes, file_MC_base_dir, False)
            plot_iter_all_ensemble_sizes(n_samples, iter, True)
            plt.grid()
            plt.ylim([75, 150])
            plt.savefig('MC_MG_case_5.png', dpi=400)
            np.savetxt('MC_MG_case_5.txt', np.transpose(iter), delimiter=' ')
        except:
            print(file_MC_base_dir + ' has not all the files')
        file_MC_base_dir = '/Volumes/HD_SONY/CMAME/Plate/MG/all/katoptron_CMAME_tests_plate_MC_MG_all_cases/case_6'
        try:
            iter = read_iter_all_ensemble_sizes(
                n_samples, ensemble_sizes, file_MC_base_dir, False)
            plot_iter_all_ensemble_sizes(n_samples, iter, True)
            plt.grid()
            plt.ylim([75, 150])
            plt.savefig('MC_MG_case_6.png', dpi=400)
            np.savetxt('MC_MG_case_6.txt', np.transpose(iter), delimiter=' ')
        except:
            print(file_MC_base_dir + ' has not all the files')
        n_samples = 96
        file_MC_base_dir = '/Users/kimliegeois/Desktop/katoptron_Juelich_tests_M1_assembly_fused_MC_NER_2'
        try:
            iter = read_iter_all_ensemble_sizes(
                n_samples, ensemble_sizes, file_MC_base_dir, False)
            plot_iter_all_ensemble_sizes(n_samples, iter, True)
            plt.grid()
            plt.ylim([190, 210])
            plt.savefig('Juelich_NER.png', dpi=400)
            np.savetxt('Juelich_NER.txt', np.transpose(iter), delimiter=' ')
            iter2 = np.transpose(iter)
            sum_iter = np.zeros((4, 1))
            for i in range(0, 4):
                sum_iter[i] = np.sum(iter2[:, i])
            print(sum_iter / sum_iter[0])
        except:
            print(file_MC_base_dir + ' has not all the files')
        file_MC_base_dir = '/Users/kimliegeois/Desktop/katoptron_Juelich_tests_M1_assembly_fused_MC_ER_2'
        try:
            iter = read_iter_all_ensemble_sizes(
                n_samples, ensemble_sizes, file_MC_base_dir, True)
            plot_iter_all_ensemble_sizes(n_samples, iter, True)
            plt.grid()
            plt.ylim([190, 310])
            plt.savefig('Juelich_ER.png', dpi=400)
            np.savetxt('Juelich_ER.txt', np.transpose(iter), delimiter=' ')
            iter2 = np.transpose(iter)
            sum_iter = np.zeros((4, 1))
            for i in range(0, 4):
                sum_iter[i] = np.sum(iter2[:, i])
            print(sum_iter / sum_iter[0])
        except:
            print(file_MC_base_dir + ' has not all the files')

        n_samples = 64
        file_MC_base_dir = '/Users/kimliegeois/Desktop/katoptron_CMAME_tests_plate_MC_MG_all_cases/case_1'
        try:
            iter = read_iter_all_ensemble_sizes(
                n_samples, ensemble_sizes, file_MC_base_dir, False)
            plot_iter_all_ensemble_sizes(n_samples, iter, True)
            plt.grid()
            plt.ylim([50, 150])
            plt.savefig('MC_MG_case_1_2.png', dpi=400)
            np.savetxt('MC_MG_case_1_2.txt', np.transpose(iter), delimiter=' ')
        except:
            print(file_MC_base_dir + ' has not all the files')
        file_MC_base_dir = '/Users/kimliegeois/Desktop/katoptron_CMAME_tests_plate_MC_MG_all_cases/case_2'
        try:
            iter = read_iter_all_ensemble_sizes(
                n_samples, ensemble_sizes, file_MC_base_dir, False)
            plot_iter_all_ensemble_sizes(n_samples, iter, True)
            plt.grid()
            plt.ylim([50, 150])
            plt.savefig('MC_MG_case_2_2.png', dpi=400)
            np.savetxt('MC_MG_case_2_2.txt', np.transpose(iter), delimiter=' ')
        except:
            print(file_MC_base_dir + ' has not all the files')

        file_MC_base_dir = '/Users/kimliegeois/Desktop/katoptron_CMAME_tests_plate_MC_MG_all_cases_4_ER/case_1'
        try:
            iter = read_iter_all_ensemble_sizes(
                n_samples, ensemble_sizes, file_MC_base_dir, True)
            plot_iter_all_ensemble_sizes(n_samples, iter, True)
            plt.grid()
            plt.ylim([50, 400])
            plt.savefig('MC_MG_case_1_ER.png', dpi=400)
            np.savetxt('MC_MG_case_1_ER.txt',
                       np.transpose(iter), delimiter=' ')
            print('MC_MG_case_1_ER')
            iter2 = np.transpose(iter)
            sum_iter = np.zeros((4, 1))
            for i in range(0, 4):
                sum_iter[i] = np.sum(iter2[:, i])
            print(sum_iter / sum_iter[0])
        except:
            print(file_MC_base_dir + ' has not all the files')
        file_MC_base_dir = '/Users/kimliegeois/Desktop/katoptron_CMAME_tests_plate_MC_MG_all_cases_4_ER/case_2'
        try:
            iter = read_iter_all_ensemble_sizes(
                n_samples, ensemble_sizes, file_MC_base_dir, True)
            plot_iter_all_ensemble_sizes(n_samples, iter, True)
            plt.grid()
            plt.ylim([50, 400])
            plt.savefig('MC_MG_case_2_ER.png', dpi=400)
            np.savetxt('MC_MG_case_2_ER.txt',
                       np.transpose(iter), delimiter=' ')
            print('MC_MG_case_2_ER')
            iter2 = np.transpose(iter)
            sum_iter = np.zeros((4, 1))
            for i in range(0, 4):
                sum_iter[i] = np.sum(iter2[:, i])
            print(sum_iter / sum_iter[0])
        except:
            print(file_MC_base_dir + ' has not all the files')
        file_MC_base_dir = '/Users/kimliegeois/Desktop/katoptron_CMAME_tests_plate_MC_MG_all_cases_4_ER/case_3'
        try:
            iter = read_iter_all_ensemble_sizes(
                n_samples, ensemble_sizes, file_MC_base_dir, True)
            plot_iter_all_ensemble_sizes(n_samples, iter, True)
            plt.grid()
            plt.ylim([50, 400])
            plt.savefig('MC_MG_case_3_ER.png', dpi=400)
            np.savetxt('MC_MG_case_3_ER.txt',
                       np.transpose(iter), delimiter=' ')
            print('MC_MG_case_3_ER')
            iter2 = np.transpose(iter)
            sum_iter = np.zeros((4, 1))
            for i in range(0, 4):
                sum_iter[i] = np.sum(iter2[:, i])
            print(sum_iter / sum_iter[0])
        except:
            print(file_MC_base_dir + ' has not all the files')
        file_MC_base_dir = '/Users/kimliegeois/Desktop/katoptron_CMAME_tests_plate_MC_MG_all_cases_4_ER/case_4'
        try:
            iter = read_iter_all_ensemble_sizes(
                n_samples, ensemble_sizes, file_MC_base_dir, True)
            plot_iter_all_ensemble_sizes(n_samples, iter, True)
            plt.grid()
            plt.ylim([50, 400])
            plt.savefig('MC_MG_case_4_ER.png', dpi=400)
            np.savetxt('MC_MG_case_4_ER.txt',
                       np.transpose(iter), delimiter=' ')
            print('MC_MG_case_4_ER')
            iter2 = np.transpose(iter)
            sum_iter = np.zeros((4, 1))
            for i in range(0, 4):
                sum_iter[i] = np.sum(iter2[:, i])
            print(sum_iter / sum_iter[0])
        except:
            print(file_MC_base_dir + ' has not all the files')
        file_MC_base_dir = '/Users/kimliegeois/Desktop/katoptron_CMAME_tests_plate_MC_MG_all_cases_4_ER/case_5'
        try:
            iter = read_iter_all_ensemble_sizes(
                n_samples, ensemble_sizes, file_MC_base_dir, True)
            plot_iter_all_ensemble_sizes(n_samples, iter, True)
            plt.grid()
            plt.ylim([50, 400])
            plt.savefig('MC_MG_case_5_ER.png', dpi=400)
            np.savetxt('MC_MG_case_5_ER.txt',
                       np.transpose(iter), delimiter=' ')
            print('MC_MG_case_5_ER')
            iter2 = np.transpose(iter)
            sum_iter = np.zeros((4, 1))
            for i in range(0, 4):
                sum_iter[i] = np.sum(iter2[:, i])
            print(sum_iter / sum_iter[0])
        except:
            print(file_MC_base_dir + ' has not all the files')
        file_MC_base_dir = '/Users/kimliegeois/Desktop/katoptron_CMAME_tests_plate_MC_MG_all_cases_4_ER/case_6'
        try:
            iter = read_iter_all_ensemble_sizes(
                n_samples, ensemble_sizes, file_MC_base_dir, True)
            plot_iter_all_ensemble_sizes(n_samples, iter, True)
            plt.grid()
            plt.ylim([50, 400])
            plt.savefig('MC_MG_case_6_ER.png', dpi=400)
            np.savetxt('MC_MG_case_6_ER.txt',
                       np.transpose(iter), delimiter=' ')
            print('MC_MG_case_6_ER')
            iter2 = np.transpose(iter)
            sum_iter = np.zeros((4, 1))
            for i in range(0, 4):
                sum_iter[i] = np.sum(iter2[:, i])
            print(sum_iter / sum_iter[0])
        except:
            print(file_MC_base_dir + ' has not all the files')
        file_MC_base_dir = '/Users/kimliegeois/Desktop/katoptron_CMAME_tests_plate_MC_MG_all_cases_4_NER/case_1'
        try:
            iter = read_iter_all_ensemble_sizes(
                n_samples, ensemble_sizes, file_MC_base_dir, False)
            plot_iter_all_ensemble_sizes(n_samples, iter, True)
            plt.grid()
            plt.ylim([100, 150])
            plt.savefig('MC_MG_case_1_NER.png', dpi=400)
            np.savetxt('MC_MG_case_1_NER.txt',
                       np.transpose(iter), delimiter=' ')
            iter2 = np.transpose(iter)
            sum_iter = np.zeros((4, 1))
            for i in range(0, 4):
                sum_iter[i] = np.sum(iter2[:, i])
            print(sum_iter / sum_iter[0])
        except:
            print(file_MC_base_dir + ' has not all the files')
        file_MC_base_dir = '/Users/kimliegeois/Desktop/katoptron_CMAME_tests_plate_MC_MG_all_cases_4_NER/case_2'
        try:
            iter = read_iter_all_ensemble_sizes(
                n_samples, ensemble_sizes, file_MC_base_dir, False)
            plot_iter_all_ensemble_sizes(n_samples, iter, True)
            plt.grid()
            plt.ylim([100, 150])
            plt.savefig('MC_MG_case_2_NER.png', dpi=400)
            np.savetxt('MC_MG_case_2_NER.txt',
                       np.transpose(iter), delimiter=' ')
            iter2 = np.transpose(iter)
            sum_iter = np.zeros((4, 1))
            for i in range(0, 4):
                sum_iter[i] = np.sum(iter2[:, i])
            print(sum_iter / sum_iter[0])
        except:
            print(file_MC_base_dir + ' has not all the files')
        file_MC_base_dir = '/Users/kimliegeois/Desktop/katoptron_CMAME_tests_plate_MC_MG_all_cases_4_NER/case_3'
        try:
            iter = read_iter_all_ensemble_sizes(
                n_samples, ensemble_sizes, file_MC_base_dir, False)
            plot_iter_all_ensemble_sizes(n_samples, iter, True)
            plt.grid()
            plt.ylim([100, 150])
            plt.savefig('MC_MG_case_3_NER.png', dpi=400)
            np.savetxt('MC_MG_case_3_NER.txt',
                       np.transpose(iter), delimiter=' ')
            iter2 = np.transpose(iter)
            sum_iter = np.zeros((4, 1))
            for i in range(0, 4):
                sum_iter[i] = np.sum(iter2[:, i])
            print(sum_iter / sum_iter[0])
        except:
            print(file_MC_base_dir + ' has not all the files')
        file_MC_base_dir = '/Users/kimliegeois/Desktop/katoptron_CMAME_tests_plate_MC_MG_all_cases_4_NER/case_4'
        try:
            iter = read_iter_all_ensemble_sizes(
                n_samples, ensemble_sizes, file_MC_base_dir, False)
            plot_iter_all_ensemble_sizes(n_samples, iter, True)
            plt.grid()
            plt.ylim([100, 150])
            plt.savefig('MC_MG_case_4_NER.png', dpi=400)
            np.savetxt('MC_MG_case_4_NER.txt',
                       np.transpose(iter), delimiter=' ')
            iter2 = np.transpose(iter)
            sum_iter = np.zeros((4, 1))
            for i in range(0, 4):
                sum_iter[i] = np.sum(iter2[:, i])
            print(sum_iter / sum_iter[0])
        except:
            print(file_MC_base_dir + ' has not all the files')
        file_MC_base_dir = '/Users/kimliegeois/Desktop/katoptron_CMAME_tests_plate_MC_MG_all_cases_4_NER/case_5'
        try:
            iter = read_iter_all_ensemble_sizes(
                n_samples, ensemble_sizes, file_MC_base_dir, False)
            plot_iter_all_ensemble_sizes(n_samples, iter, True)
            plt.grid()
            plt.ylim([100, 150])
            plt.savefig('MC_MG_case_5_NER.png', dpi=400)
            np.savetxt('MC_MG_case_5_NER.txt',
                       np.transpose(iter), delimiter=' ')
            iter2 = np.transpose(iter)
            sum_iter = np.zeros((4, 1))
            for i in range(0, 4):
                sum_iter[i] = np.sum(iter2[:, i])
            print(sum_iter / sum_iter[0])
        except:
            print(file_MC_base_dir + ' has not all the files')
        file_MC_base_dir = '/Users/kimliegeois/Desktop/katoptron_CMAME_tests_plate_MC_MG_all_cases_4_NER/case_6'
        try:
            iter = read_iter_all_ensemble_sizes(
                n_samples, ensemble_sizes, file_MC_base_dir, False)
            plot_iter_all_ensemble_sizes(n_samples, iter, True)
            plt.grid()
            plt.ylim([100, 150])
            plt.savefig('MC_MG_case_6_NER.png', dpi=400)
            np.savetxt('MC_MG_case_6_NER.txt',
                       np.transpose(iter), delimiter=' ')
            iter2 = np.transpose(iter)
            sum_iter = np.zeros((4, 1))
            for i in range(0, 4):
                sum_iter[i] = np.sum(iter2[:, i])
            print(sum_iter / sum_iter[0])
        except:
            print(file_MC_base_dir + ' has not all the files')


if __name__ == "__main__":
    main()
