#!/usr/bin/env python3
# -*- coding: utf-8; -*-




from katoptron.speedup import *


def speedup_of_one_case(case_id, GS, ensemble_reduction, n_samples, ensemble_sizes, quantiles, querylines, use_waves_timers, use_teuchos_timers, per_iteration):
    import matplotlib.pyplot as plt
    if GS:
        prec = 'GS_'
    else:
        prec = 'direct_'

    if ensemble_reduction:
        case_id = str(case_id)+'_ER'
    else:
        case_id = str(case_id)+'_NER'

    file_MC_base_dir = '/Volumes/HD_SONY/CMAME/Plate/katoptron_CMAME_tests_plate_MC_' + \
        prec+'case_' + case_id
    try:
        speedup = compute_speedup(n_samples, ensemble_sizes, file_MC_base_dir, querylines,
                                  per_iteration, quantiles, use_waves_timers, use_teuchos_timers, ensemble_reduction)

        plot_speedup(speedup, ensemble_sizes, np.arange(
            0, len(querylines)), prec+'case_' + case_id, querylines, per_iteration)
        plt.savefig(prec+'case_' + case_id + '.png', dpi=400)

        save_speedup(speedup, ensemble_sizes,
                     querylines, prec+'case_' + case_id)

        R = compute_R(n_samples, ensemble_sizes, file_MC_base_dir,
                      quantiles, ensemble_reduction)
        save_R(R, 'R_'+prec+'case_' + case_id)
    except:
        print('/Volumes/HD_SONY/CMAME/Plate/katoptron_CMAME_tests_plate_MC_' +
              prec+'case_' + case_id + '  has not all the files')


def main():
    import matplotlib.pyplot as plt

    n_samples = 32
    ensemble_sizes = [1, 8, 16, 32]
    quantiles = [0, 0.33, 0.5, 0.66, 1.]

    querylines = ['computeMatrices', 'Belos: Operation Op*x', 'Belos: Operation Prec*x', 'Belos: DGKS[2]: Orthogonalization',
                  'Belos: DGKS[2]: Ortho (Inner Product)', 'Belos: DGKS[2]: Ortho (Norm)', 'Belos: DGKS[2]: Ortho (Update)', 'total']
    use_waves_timers = np.array([0, 7], dtype=int)
    use_teuchos_timers = np.array([1, 2, 3, 4, 5, 6], dtype=int)
    per_iteration = [False, True, True, False, False, False, False, False]

    for i in range(1, 5):
        speedup_of_one_case(i, False, True, n_samples, ensemble_sizes, quantiles,
                            querylines, use_waves_timers, use_teuchos_timers, per_iteration)
        speedup_of_one_case(i, True, True, n_samples, ensemble_sizes, quantiles,
                            querylines, use_waves_timers, use_teuchos_timers, per_iteration)
        speedup_of_one_case(i, False, False, n_samples, ensemble_sizes, quantiles,
                            querylines, use_waves_timers, use_teuchos_timers, per_iteration)
        speedup_of_one_case(i, True, False, n_samples, ensemble_sizes, quantiles,
                            querylines, use_waves_timers, use_teuchos_timers, per_iteration)


if __name__ == "__main__":
    main()
