// This .geo has been tested with gmsh 3.0.6 and 4.4.1 binaries for Mac and Linux

Macro Clear_all
  allVolumes[] = Volume "*";
  Recursive Delete { Volume{allVolumes[] } ; }
  allSurfaces[] = Surface "*";
  Recursive Delete { Surface{allSurfaces[] } ; }  
  allPoints[] = Point "*";
  Recursive Delete { Point{allPoints[] } ; }    
Return

Macro Compute_next_avaible_point_id
  allPoints[] = Point "*" ;
  NallPoints = #allPoints[] ;
  Printf("NallPoints %f",NallPoints);
  next_avaible_point_id = 0;
  compute_next_avaible_point_id_verbose = 0;
  For i In {0:NallPoints-1}
    If(compute_next_avaible_point_id_verbose)
      Printf("Compute_next_avaible_point_id %g, %g",i,allPoints[i]);
    EndIf
    If(allPoints[i]>= next_avaible_point_id)
      next_avaible_point_id = allPoints[i] + 1;
    EndIf
  EndFor
  Printf("Compute_next_avaible_point_id newp %g",newp);
  Printf("Compute_next_avaible_point_id next_avaible_point_id %g",next_avaible_point_id);
Return

Macro Scale_axis_mm_to_m
  allPoints[] = Point "*" ;
  allLines[] = Line "*" ;
  allSurfaces[] = Surface "*";
  allVolumes[] = Volume "*";
  If(usePointID)
    c1[] = Point{point_OO};
  EndIf
  Dilate {{-c1[0],-c1[1],-c1[2]},0.001} { Volume{allVolumes[] } ; }

  allPoints[] = Point "*" ;
  allLines[] = Line "*" ;
  allSurfaces[] = Surface "*";
  allVolumes[] = Volume "*";
Return

Macro Weld_bolt
  new_weld_line_loop = newreg;
  Curve Loop(new_weld_line_loop) = curves_id_1[];
  Plane Surface(new_weld_line_loop) = {new_weld_line_loop};
  num[] = Extrude {0, 0, 0.026} {
    Surface{new_weld_line_loop};
  };
  new_volume_1 = num[1];
  num[] = Extrude {0, 0, -0.012} {
    Surface{new_weld_line_loop};
  };
  new_volume_2 = num[1];
  new_weld_line_loop = newreg;
  Curve Loop(new_weld_line_loop) = curves_id_2[];
  Plane Surface(new_weld_line_loop) = {new_weld_line_loop};
  num[] = Extrude {0, 0, 0.002} {
    Surface{new_weld_line_loop};
  };
  new_volume_3 = num[1];
  new_weld_line_loop = newreg;
  Curve Loop(new_weld_line_loop) = curves_id_3[];
  Plane Surface(new_weld_line_loop) = {new_weld_line_loop};
  num[] = Extrude {0, 0, -0.006} {
    Surface{new_weld_line_loop};
  };
  new_volume_4 = num[1];
  num[] = BooleanUnion{ Volume{volume_id_1}; Delete; }{ Volume{volume_id_2}; Volume{volume_id_3}; Volume{volume_id_4}; Volume{volume_id_5}; Volume{volume_id_6}; Volume{volume_id_7}; Volume{volume_id_8}; Volume{volume_id_9}; Volume{new_volume_1}; Volume{new_volume_2}; Volume{new_volume_3}; Volume{new_volume_4}; Delete; };
  new_volume_1 = num[0];
Return

Macro Weld_tube
  c1[] = Point{pipe_p1};
  c2[] = Point{pipe_p2};
  center1[] = {(c1[0]+c2[0])/2, (c1[1]+c2[1])/2, (c1[2]+c2[2])/2};
  pipe_radius = Sqrt((c1[0]-center1[0])^2+(c1[1]-center1[1])^2+(c1[2]-center1[2])^2);

  c1[] = Point{weld_p1};
  c2[] = Point{weld_p5};
  center1[] = {(c1[0]+c2[0])/2, (c1[1]+c2[1])/2, (c1[2]+c2[2])/2};
  weld_radius = Sqrt((c1[0]-center1[0])^2+(c1[1]-center1[1])^2+(c1[2]-center1[2])^2);

  new_weld_p1 = newp;
  Point(new_weld_p1) = {(pipe_radius/weld_radius)*(c1[0]-center1[0])+center1[0],(pipe_radius/weld_radius)*(c1[1]-center1[1])+center1[1],(pipe_radius/weld_radius)*(c1[2]-center1[2])+center1[2]};
  new_weld_line1 = newreg; Line(new_weld_line1) = {new_weld_p1, weld_p2};
  new_weld_line2 = newreg; Line(new_weld_line2) = {weld_p2, weld_p3};
  new_weld_line3 = newreg; Line(new_weld_line3) = {weld_p3, weld_p4};
  new_weld_line4 = newreg; Line(new_weld_line4) = {weld_p4, new_weld_p1};

  new_weld_line_loop = newreg;  Line Loop(new_weld_line_loop) = {new_weld_line1,new_weld_line2,new_weld_line3,new_weld_line4};
  Plane Surface(new_weld_line_loop) = {new_weld_line_loop};

  c1[]=Point{weld_p3};
  c2[]=Point{weld_p4};

  Extrude {{c2[0]-c1[0],c2[1]-c1[1],c2[2]-c1[2]}, {center1[0], center1[1], center1[2]}, Pi} {
    Surface{new_weld_line_loop};
  }
  Extrude {{c2[0]-c1[0],c2[1]-c1[1],c2[2]-c1[2]}, {center1[0], center1[1], center1[2]}, -Pi} {
    Surface{new_weld_line_loop};
  }
Return

Macro Compute_cross_and_theta
  norm_1 = Sqrt(vec_1[0]^2+vec_1[1]^2+vec_1[2]^2);
  norm_2 = Sqrt(vec_2[0]^2+vec_2[1]^2+vec_2[2]^2);

  cross[] = {vec_1[1]*vec_2[2]-vec_1[2]*vec_2[1],vec_1[2]*vec_2[0]-vec_1[0]*vec_2[2],vec_1[0]*vec_2[1]-vec_1[1]*vec_2[0]};
  norm_cross = Sqrt(cross[0]^2+cross[1]^2+cross[2]^2);

  dot = vec_1[0]*vec_2[0] + vec_1[1]*vec_2[1] + vec_1[2]*vec_2[2];

  theta = Acos(dot/(norm_1*norm_2));
Return

Macro Rotate_Axis
  allVolumes[] = Volume "*";
  If(usePointID)
    c1[] = Point{point_OX_1};
    c2[] = Point{point_OX_2};
    Printf("Rotate_Axis point_OX_1 c1 (%g,%g,%g)",c1[0],c1[1],c1[2]);
    Printf("Rotate_Axis point_OX_2 c2 (%g,%g,%g)",c2[0],c2[1],c2[2]);
  EndIf

  OX[] = {c2[0]-c1[0],c2[1]-c1[1],c2[2]-c1[2]};
  vec_1[] = OX[];
  vec_2[] = {1,0,0};

  Call Compute_cross_and_theta;

  Rotate {{cross[0],cross[1],cross[2]}, {0, 0, 0}, theta} { Volume{allVolumes[] } ; }

  allVolumes[] = Volume "*";
  If(usePointID)
    c3[] = Point{point_OY_1};
    c4[] = Point{point_OY_2};
    Printf("Rotate_Axis point_OY_1 c3 (%g,%g,%g)",c3[0],c3[1],c3[2]);
    Printf("Rotate_Axis point_OY_2 c4 (%g,%g,%g)",c4[0],c4[1],c4[2]);
  EndIf

  OY[] = {c4[0]-c3[0],c4[1]-c3[1],c4[2]-c3[2]};
  vec_1[] = OY[];
  vec_2[] = {0,1,0};

  Call Compute_cross_and_theta;
  Rotate {{cross[0],cross[1],cross[2]}, {0, 0, 0}, theta} { Volume{allVolumes[] } ; }

Return

Macro Translate_Axis
  allVolumes[] = Volume "*";
  If(usePointID)
    c1[] = Point{point_OO};
    Printf("Translate_Axis point_OO c1 (%g,%g,%g)",c1[0],c1[1],c1[2]);
  EndIf
  Translate {-c1[0],-c1[1],-c1[2]} { Volume{allVolumes[] } ; }
  allVolumes[] = Volume "*";
Return

Macro Contact_disk
  c1[] = Point{point_disk_R_1};
  c2[] = Point{point_disk_R_2};

  center[] = {(c1[0]+c2[0])/2, (c1[1]+c2[1])/2, (c1[2]+c2[2])/2};

  R = Sqrt((c1[0]-center[0])^2+(c1[1]-center[1])^2+(c1[2]-center[2])^2);

  c1[] = Point{point_surface_disk_1};
  c2[] = Point{point_surface_disk_2};

  new_disk = newreg;
  Disk(new_disk) = {(c1[0]+c2[0])/2, (c1[1]+c2[1])/2, (c1[2]+c2[2])/2, R, R};

  Printf("c1 (%g,%g,%g)",c1[0],c1[1],c1[2]);
  Printf("c2 (%g,%g,%g)",c2[0],c2[1],c2[2]);
  Printf("Center (%g,%g,%g) radius %g",(c1[0]+c2[0])/2, (c1[1]+c2[1])/2, (c1[2]+c2[2])/2, R) ;

  BooleanFragments{ Surface{new_disk}; Delete; }{ Volume{volume_id}; Delete; }
Return

Macro Add_Optical_Axis
  If(usePointID)
    p1[] = Point{point_mirror_x};
    p2[] = Point{point_mirror_y};
    Printf("Add_Optical_Axis p1 (%g,%g,%g)",p1[0],p1[1],p1[2]);
    Printf("Add_Optical_Axis p2 (%g,%g,%g)",p2[0],p2[1],p2[2]);
  EndIf

  Printf("Add_Optical_Axis OA (%g,%g,%g)",p1[0]+Delta_x,p2[1]+Delta_y,p1[2]);

  Call Compute_next_avaible_point_id;
  OA = next_avaible_point_id;
  Point(OA) = {p1[0]+Delta_x, p2[1]+Delta_y, p1[2], 1};
  new_disk = newreg;
  Disk(new_disk) = {p1[0]+Delta_x, p2[1]+Delta_y, p1[2], R, R};

  BooleanFragments{  Point{OA}; Surface{new_disk}; Delete; }{ Volume{Mirror_id}; Delete; }
  //BooleanFragments{  Point{OA}; Delete; }{ Volume{Mirror_id}; Delete; }
Return

SetFactory("OpenCASCADE");

rerun = 0;

If(!FileExists("fused_mirror_assembly_mm.brep") || rerun)
  v() = ShapeFromFile("mirror_assembly.stp");

  For k In {20:23:1}
    Recursive Delete { Volume{k}; }
  EndFor

  For k In {27:62:1}
    Recursive Delete { Volume{k}; }
  EndFor

  allVolumes[] = Volume "*";
  BooleanFragments{ Volume{allVolumes[] }; Delete; }{}

  usePointID = 0;

  // Realign the axis

  If(usePointID)
    point_OX_1 = 835;
    point_OX_2 = 834;

    point_OY_1 = 938;
    point_OY_2 = 940;
  Else
    c1[] = {6450.86,-90.1101,4467.16};
    c2[] = {6425.67,-76.908,4448.46};

    c3[] = {-7294.05,1085.32,2738.15};
    c4[] = {-7294.05,1121.25,2759.9};
  EndIf

  Call Rotate_Axis;

  If(usePointID)
    point_OO = 938;
  Else
    c1[] = {-7294.05,2346.64,1780.06};
  EndIf

  Call Translate_Axis;

  usePointID = 1;

  If(usePointID)
    point_mirror_x = 4046;
    point_mirror_y = 4045;
  Else
    p1[] = {129.5,10,5.1462499};
    p2[] = {99.5,-20,5.1462499};
  EndIf

  Delta_x = -70;
  Delta_y = 37;

  Mirror_id = 2;
  R = 1.;

  //Call Add_Optical_Axis;

  Recursive Delete { Volume{3,17,18}; }

  Save "fused_mirror_assembly_mm.brep";
  Call Clear_all;
EndIf

Merge "fused_mirror_assembly_mm.brep";  

Physical Volume("Mirror") = {2};
Physical Volume("Substrate") = {1};
Physical Volume("Washer 1") = {5};
Physical Volume("Washer 2") = {4};
Physical Volume("Washer 3") = {3};

Physical Volume("Shaft 1") = {8};
Physical Volume("Shaft 2") = {7};
Physical Volume("Shaft 3") = {6};  

Physical Volume("Spacer 1 part 1") = {12};
Physical Volume("Spacer 2 part 1") = {11};
Physical Volume("Spacer 3 part 1") = {9};

Physical Volume("Spacer 1 part 2") = {14};
Physical Volume("Spacer 2 part 2") = {13};
Physical Volume("Spacer 3 part 2") = {10};

Physical Volume("Holder") = {15,16};

Physical Volume("Nut 1") = {18};
Physical Volume("Nut 2") = {19};
Physical Volume("Nut 3") = {17};

Physical Surface("Mirror surface") = {113};
//Physical Surface("Disk around optical axis") = {738};

Physical Surface("Cooling channels") = {524, 525, 526, 597, 598, 599, 619, 620};

For k In {497:522}
  Physical Surface("Cooling channels") += {k};
EndFor

Physical Surface("Holder z clamping") = {544, 545, 562, 563, 572, 573};
Physical Surface("Holder x-y clamping") = {553, 554, 546, 547, 568, 569};

Physical Point("Holder x-y-z clamping point") = {762};
Physical Point("Holder z clamping point") = {740};
Physical Point("Holder z-y clamping point") = {733};

Physical Point("Optical Axis") = {958};


Mesh.Algorithm = 6;
//Mesh.Algorithm3D = 4;
Mesh.CharacteristicLengthMin = 1.5;
Mesh.CharacteristicLengthMax = 1.5;
Mesh.MshFileVersion = 2.2;
