/*
 * Copyright 2022 University of Liège
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#ifndef WMEDIUM_H
#define WMEDIUM_H

#include "mirrors.h"
#include "wGroup.h"
#include <string>

using namespace tbox;

namespace mirrors
{

/**
 * @brief a thermomechanical medium
 */

class MIRRORS_API Medium : public Group
{
public:
    std::string medium_name;
    double E;  ///< Young's modulus
    double nu; ///< Poisson coefficient
    double k;  ///< Conductivity
    double beta;
    Medium(Problem &pbl, int no, std::string _medium_name,
           double _E = 1000., double _nu = 0., double _k = 0., double _beta = 0.);
    Medium(Problem &pbl, std::string const &name, std::string _medium_name,
           double _E = 1000., double _nu = 0., double _k = 0., double _beta = 0.);

#ifndef SWIG
    virtual void write(std::ostream &out) const override;
#endif
};

} // namespace mirrors

#endif //WMEDIUM_H
