#!/usr/bin/env python3
# -*- coding: utf-8 -*-

# Copyright 2022 University of Liège
# 
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
# 
#     http://www.apache.org/licenses/LICENSE-2.0
# 
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.


import numpy as np
import time
import os
import shutil
import math

from params.src.func import grid 
from params.src.func import next_indices
from params.src.func import phi

from fwk.wutils import parseargs
args = parseargs()
if not args.nogui:
    from matplotlib import cm
    import matplotlib.pyplot as plt
    from mpl_toolkits.mplot3d import Axes3D


def model(xi,f,d,fig,ax,imported_sol,m_i):

    import mirrors.models.mirror_ss as mirror_model

    T_min = 100.
    T_max = 300.

    H_1_min = 2
    H_1_max = 10

    L0 = 250.0
    L0_1 = 250.0
    H0 = 50
    H0_1 = 30 
    W0 = 150

    nL0_1 = 6 # 31 #11
    nL0 =  6 #  31 #11  
    nH0 =  3 #  21 #6
    nH0_1 = 3 #  11 #6
    nW0 =  2 # 25 #5

    #sol = mirror_model.runmodel(L = L0, L_1 = L0_1, H = H0, H_1 = xi[1], W = W0, nL_1 = nL0_1, nL = nL0, nH = nH0, nH_1 = nH0_1, nW = nW0, T = xi[0])
    #sol = 1

    sol = imported_sol[m_i]


    f.write('T = ' + str(xi[0]) + '.\n')
    f.write('Sol = ' + str(sol) + '.\n')
    if not args.nogui:
        plot(xi,sol,d,fig,ax)

    return sol

def plot(xi,sol,d,fig,ax):
    plt.figure(fig.number)
    if d == 1:
        plt.scatter(xi[0])
    elif d == 2: 
        ax.scatter(xi[0],xi[1])
    plt.pause(.001)

def main():

    d = 2
    k = 25 #  [RB] =5*5? was 100=10*10
    M = np.zeros((d,), dtype =np.int)
    N = np.zeros((d,), dtype =np.int)
    for j in range(0,d):
        M[j] = 5 # [RB] was 10
        N[j] = 5 # [RB] was 10

    Dom_min = np.array([ -1., -1.])
    Dom_max = np.array([ 1., 1.])

    imported_sol = np.array([ 1 ])

    
    #----------

    date = time.strftime("%d/%m/%Y")
    hour = time.strftime("%H:%M:%S")

    f = open('params_sol2.log','w')
    f.write('Parametric loop\n')
    f.write('Simulations started at: ' + date + ' ' + hour + '.\n')
    f.write('====================\n')

    X, w = grid(M)  

    print(M)
    print(X)

    m_max = 1
    n_max = 1 #math.factorial(N[0]+d)/(math.factorial(N[0])*math.factorial(d))
    for j in range(0,d):
        m_max = m_max*M[j] 
        n_max = n_max*N[j]

    print(m_max)
    print(n_max)

    i =      np.zeros((d,), dtype =np.int)
    i_zero = np.zeros((d,), dtype =np.int)
    i_one =  np.ones((d,), dtype =np.int)
    p = 0

    xi = np.zeros((d,))

    if not args.nogui:
        fig = plt.figure()
        if d == 1:
            ax = fig.gca()
            #ax.axis([100, 300, 20, 100])
        elif d == 2: 
            ax = fig.gca()
            ax.set_xlabel('T [C]')
            ax.set_ylabel('H_1 [mm]')
        plt.ion()

        current_title = plt.title("Training points")

        if not os.path.exists('images'):
            os.mkdir('images')
        else:
            shutil.rmtree('images')
            os.mkdir('images')
    else:
        fig = None
        ax = None

    m_i = 0
    sol = np.zeros((m_max,1))

    Z = np.zeros((m_max,n_max))
    W = np.zeros((m_max,m_max))
    W_sr = np.zeros((m_max,m_max))

    while np.all(i != -i_one):

        name = 'i_'
        for j in range(0,d-1):
            name = name + str(i[j]) + '_'
        name = name + str(i[d-1]) + '_'
        name = name + 'M_' 
        for j in range(0,d-1):
            name = name + str(M[j]) + '_'
        name = name + str(M[d-1]) 

        f.write(name + '\n')

        if not os.path.exists(name):
            os.mkdir(name)
        else:
            shutil.rmtree(name)
            os.mkdir(name)

        os.chdir(name)

        for j in range(0,d):
            xi[j] = X[i[j],j]
            xi[j] = Dom_min[j] + (Dom_max[j] - Dom_min[j])*(xi[j]+1.)/2.

        Z[m_i,:] = np.transpose(phi(xi,N,n_max,d))
        sol[m_i] = model(xi,f,d,fig,ax,imported_sol,m_i)
        

        W[m_i,m_i] = 1
        for j in range(0,d):
            W[m_i,m_i] = W[m_i,m_i]*w[i[j],j]

        W_sr[m_i,m_i]  = np.sqrt(W[m_i,m_i])
        os.chdir('..')

        if not args.nogui:
            plt.draw()
            #os.chdir('images')
            #plt.savefig('training_point' + str(m_i+1) + '.png', bbox_inches = 'tight')
            #os.chdir('..')
        #m_i = m_i + 1

        p,i = next_indices(p,i,M,d)

        
        

    W_srZ = np.dot(W_sr,Z)
    U, s, V_t = np.linalg.svd(W_srZ, full_matrices=True)
    if not args.nogui:
        fig = plt.figure()
        plt.semilogy(list(range(1,n_max+1)),s,'ko')
        ax = fig.gca()
        ax.set_xlabel('i [-]')
        ax.set_ylabel('sigma_i [-]')
        os.chdir('images')
        plt.savefig('SVD.png', bbox_inches = 'tight')
        os.chdir('..')

    date2 = time.strftime("%d/%m/%Y")
    hour2 = time.strftime("%H:%M:%S")
    f.write('====================\n')
    f.write('Simulations finished at: ' + date2 + ' ' + hour2 + '.\n')

    f.close()

    if not args.nogui:
        plt.ioff()
        plt.show()
    
    

if __name__ == "__main__":
    main()
